#!/bin/sh
echo 'name: lens
version: 3.8.7.3
id: lens-3.8.7.3-4b14e8dc8de670d9d40054af3aeffeb2

license: BSD3
copyright: Copyright (C) 2012-2013 Edward A. Kmett
maintainer: Edward A. Kmett <ekmett@gmail.com>
stability: provisional
homepage: http://github.com/ekmett/lens/
package-url:
synopsis: Lenses, Folds and Traversals
description: This package comes \"Batteries Included\" with many useful lenses for the types
             commonly used from the Haskell Platform, and with tools for automatically
             generating lenses and isomorphisms for user-supplied data types.
             .
             The combinators in @Control.Lens@ provide a highly generic toolbox for composing
             families of getters, folds, isomorphisms, traversals, setters and lenses and their
             indexed variants.
             .
             An overview, with a large number of examples can be found in the @README@: <https://github.com/ekmett/lens#lens-lenses-folds-and-traversals>
             .
             A video on how to use lenses and how they are constructed is available from youtube: <http://youtu.be/cefnmjtAolY?hd=1>
             .
             Slides can be obtained here: <http://comonad.com/haskell/Lenses-Folds-and-Traversals-NYC.pdf>
             .
             More information on the care and feeding of lenses, including a brief tutorial and motivation
             for their types can be found on the lens wiki: <https://github.com/ekmett/lens/wiki>
             .
             A small game of @pong@ and other more complex examples that manage their state using lenses can be found in the example folder: <https://github.com/ekmett/lens/blob/master/examples/>
             .
             /Lenses, Folds and Traversals/
             .
             The core of the hierarchy of lens-like constructions looks like:
             .
             <<http://i.imgur.com/RFi75.png>>
             .
             You can compose any two elements of the hierarchy above using @(.)@ from the @Prelude@, and you can
             use any element of the hierarchy as any type it linked to above it.
             .
             The result is their lowest upper bound in the hierarchy (or an error if that bound doesn'\''t exist).
             .
             For instance:
             .
             * You can use any '\''Traversal'\'' as a '\''Fold'\'' or as a '\''Setter'\''.
             .
             * The composition of a '\''Traversal'\'' and a '\''Getter'\'' yields a '\''Fold'\''.
             .
             /Minimizing Dependencies/
             .
             If you want to provide lenses and traversals for your own types in your own libraries, then you
             can do so without incurring a dependency on this (or any other) lens package at all.
             .
             /e.g./ for a data type:
             .
             > data Foo a = Foo Int Int a
             .
             You can define lenses such as
             .
             > -- bar :: Lens'\'' (Foo a) Int
             > bar :: Functor f => (Int -> f Int) -> Foo a -> f (Foo a)
             > bar f (Foo a b c) = fmap (\a'\'' -> Foo a'\'' b c) (f a)
             .
             > -- baz :: Lens (Foo a) (Foo b) a b
             > quux :: Functor f => (a -> f b) -> Foo a -> f (Foo b)
             > quux f (Foo a b c) = fmap (Foo a b) (f c)
             .
             without the need to use any type that isn'\''t already defined in the @Prelude@.
             .
             And you can define a traversal of multiple fields with '\''Control.Applicative.Applicative'\'':
             .
             > -- traverseBarAndBaz :: Traversal'\'' (Foo a) Int
             > traverseBarAndBaz :: Applicative f => (Int -> f Int) -> Foo a -> f (Foo a)
             > traverseBarAndBaz f (Foo a b c) = Foo <$> f a <*> f b <*> pure c
             .
             What is provided in this library is a number of stock lenses and traversals for
             common haskell types, a wide array of combinators for working them, and more
             exotic functionality, (/e.g./ getters, setters, indexed folds, isomorphisms).
category: Data, Lenses
author: Edward A. Kmett
exposed: True
exposed-modules: Control.Exception.Lens Control.Lens
                 Control.Lens.Action Control.Lens.At Control.Lens.Combinators
                 Control.Lens.Cons Control.Lens.Each Control.Lens.Equality
                 Control.Lens.Fold Control.Lens.Getter Control.Lens.Indexed
                 Control.Lens.Internal Control.Lens.Internal.Action
                 Control.Lens.Internal.Bazaar Control.Lens.Internal.ByteString
                 Control.Lens.Internal.Context Control.Lens.Internal.Deque
                 Control.Lens.Internal.Exception Control.Lens.Internal.Fold
                 Control.Lens.Internal.Getter Control.Lens.Internal.Indexed
                 Control.Lens.Internal.Instances Control.Lens.Internal.Iso
                 Control.Lens.Internal.Level Control.Lens.Internal.Magma
                 Control.Lens.Internal.Prism Control.Lens.Internal.Review
                 Control.Lens.Internal.Setter Control.Lens.Internal.Zipper
                 Control.Lens.Internal.Zoom Control.Lens.Iso Control.Lens.Lens
                 Control.Lens.Level Control.Lens.Loupe Control.Lens.Operators
                 Control.Lens.Plated Control.Lens.Prism Control.Lens.Reified
                 Control.Lens.Review Control.Lens.Setter Control.Lens.Simple
                 Control.Lens.TH Control.Lens.Traversal Control.Lens.Tuple
                 Control.Lens.Type Control.Lens.Wrapped Control.Lens.Zipper
                 Control.Lens.Zoom Control.Monad.Error.Lens
                 Control.Parallel.Strategies.Lens Control.Seq.Lens Data.Array.Lens
                 Data.Bits.Lens Data.ByteString.Lens Data.ByteString.Strict.Lens
                 Data.ByteString.Lazy.Lens Data.Complex.Lens Data.Data.Lens
                 Data.Dynamic.Lens Data.HashSet.Lens Data.IntSet.Lens Data.List.Lens
                 Data.List.Split.Lens Data.Sequence.Lens Data.Set.Lens
                 Data.Text.Lens Data.Text.Strict.Lens Data.Text.Lazy.Lens
                 Data.Tree.Lens Data.Typeable.Lens Data.Vector.Lens
                 Data.Vector.Generic.Lens Generics.Deriving.Lens GHC.Generics.Lens
                 System.Exit.Lens System.FilePath.Lens System.IO.Error.Lens
                 Language.Haskell.TH.Lens Numeric.Lens
hidden-modules:
trusted: False
import-dirs: /usr/local/lib/ghc-7.4.2/cabal/lens-3.8.7.3
library-dirs: /usr/local/lib/ghc-7.4.2/cabal/lens-3.8.7.3
              /usr/local/lib
hs-libraries: HSlens-3.8.7.3
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: MonadCatchIO-transformers-0.3.0.0-76541279080d15c89bf5cb94558aa9e1
         array-0.4.0.0-0b6c5ca7e879a14d110ca4c001dd9297
         base-4.5.1.0-f58939ca866a8377999e7a71aa62d1d0
         bifunctors-3.2.0.1-b7cff7d2f2ee46a2a7a28f68802ebef8
         bytestring-0.9.2.1-4cc8a513193316dfe32ba33f47609c9d
         comonad-3.0.2-48fa0b4cd584416476c0cace0bb27a4d
         comonad-transformers-3.0.1-7b45af534ab9a1a97bf2d87d58272729
         comonads-fd-3.0.1-09217c8978081f4dade522ca7da3900c
         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
         contravariant-0.4-304cc2911a21606b756a87698bff1b80
         distributive-0.3.1-aec96b9c702aaac88d09d56594f5e190
         filepath-1.3.0.0-f998e5510c76a98913f57b14b4f16c57
         generic-deriving-1.4.0-95058a57799bedb2d951433d088743e2
         ghc-prim-0.2.0.0-7d3c2c69a5e8257a04b2c679c40e2fa7
         hashable-1.2.0.5-1049ae1ef267f5e5664cf9f54e9a7458
         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
         parallel-3.2.0.3-4cdd6067624f867b253b98d6d9fb9f52
         profunctor-extras-3.3-e8fa445ecefeb74a5564678601952060
         profunctors-3.3-61928fcce4ad076253a66fc709341737
         reflection-1.1.7-c762228d46ac62c91a8bed33d61f5634
         semigroupoids-3.0.2-4ed985543ddc8dc384db959c7e1f734e
         semigroups-0.9-5d1f5343482e423967607642c4cfeebb
         split-0.2.1.1-03ec5738edb34f2e8967d25637b9392f
         tagged-0.4.4-886769b727dcf06f0418d254f5119104
         template-haskell-2.7.0.0-7e67d8656fb5483949028e81ed6cf7d4
         text-0.11.2.3-116e588a2afe9f305204001245768a0d
         transformers-0.3.0.0-8e66ecc7d4dae2b07b2b5406908c70e4
         unordered-containers-0.2.3.0-eea23be98f84f4fcc4f43b6a5a4ec815
         vector-0.10.0.1-3450daae3d9f2092020075d05481123c
         void-0.5.11-a88f44f0e8fc1d21f0c1a23f0996294f
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.4.2/cabal/lens-3.8.7.3/html/lens.haddock
haddock-html: /usr/local/share/doc/ghc-7.4.2/cabal/lens-3.8.7.3/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
